@@ -1,26 +1,37 @@
-#!/cygdrive/c/Python24/python.exe
+#!/usr/bin/env python
 """FileManifest.py: This is a class for automatically creating and
    verifying file manifests for installed code."""
 
-# Copyright (C) 2005 Shawn Sherwood
+# BSD License
+# Copyright (c) 2009, Shawn Sherwood
+# All rights reserved.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions are met:
+#
+# * Redistributions of source code must retain the above copyright notice,
+#   this list of conditions and the following disclaimer.
+# * Redistributions in binary form must reproduce the above copyright notice,
+#   this list of conditions and the following disclaimer in the documentation
+#   and/or other materials provided with the distribution.
+# * Neither the name of the GE Security nor the names of its contributors may
+#   be used to endorse or promote products derived from this software without
+#   specific prior written permission.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+# POSSIBILITY OF SUCH DAMAGE.
 
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation; either version 2
-# of the License, or (at your option) any later version.
-
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
-# MA  02110-1301, USA.
-
-import yaml, os
-import hashlib
+import os
+from mini_utility import md5_sum, make_path, yaml_load, yaml_dump
 
 class FileManifest:
     """File manifest creation and verification class"""
@@ -31,7 +42,7 @@ class FileManifest:
         if md5_extensions == None:
             md5_extensions = []
         self.md5_extensions = md5_extensions
-        self.root_dir = root_dir
+        self.root_dir = root_dir.replace("\\", "/")
         self.manifest_dictionary = {}
         self.sub_dirs = sub_dirs
         self.manifest_path = manifest_path
@@ -41,22 +52,22 @@ class FileManifest:
         for inode in os.listdir( self.root_dir ):
             if inode in self.sub_dirs:
                 temp_dictionary = {}
-                full_path = os.path.join( self.root_dir, inode )
+                full_path = make_path( self.root_dir, inode )
                 if os.path.isdir( full_path ):
                     self.manifest_dictionary[inode] = \
                       self.create_path_dictionary( full_path, temp_dictionary )
 
     def write_manifest_file(self):
-        """Write out the yaml for the manifest to the expected path"""
-        yaml_string = yaml.dump( self.manifest_dictionary )
+        """Write out the json or yaml for the manifest to the expected path"""
+        dump_string = yaml_dump( self.manifest_dictionary )
         handle = open( self.manifest_path, "w" )
-        handle.write( yaml_string )
+        handle.write( dump_string )
         handle.close()
         
     def create_path_dictionary( self, path, work_dict ):
         """Loop through the directories gathering data into the manifest"""
         for inode in os.listdir( path ):
-            full_path = os.path.join( path, inode )
+            full_path = make_path( path, inode )
             relative_path = self.get_relative_path(full_path)
             if os.path.isdir( full_path ):
                 self.create_path_dictionary( full_path, work_dict )
@@ -64,7 +75,7 @@ class FileManifest:
                 if inode.split('.')[-1].lower() in self.md5_extensions:
                     handle = open( full_path, 'rb' )
                     data = handle.read()
-                    work_dict[relative_path] = hashlib.md5( data ).hexdigest()
+                    work_dict[relative_path] = md5_sum(data)
                     handle.close()
                 else:
                     work_dict[relative_path] = ''
@@ -72,13 +83,14 @@ class FileManifest:
 
     def get_relative_path( self, full_path ):
         """Utility function that creates a relative path from a full path"""
-        path_from_subdir = full_path.split( self.root_dir + os.sep )[-1] 
-        return( os.sep.join( path_from_subdir.split( os.sep )[1:] ) )
+        path_from_subdir = full_path.split( self.root_dir + '/' )[-1] 
+        rel_path = '/'.join( path_from_subdir.split( '/' )[1:] ) 
+        return( rel_path ) 
 
     def load_manifest( self ):
         """Initialize manifest_dictionary from the existing manifest_path"""
-        yaml_string = open( self.manifest_path, 'r' ).read()
-        self.manifest_dictionary = yaml.load(yaml_string)
+        load_string = open( self.manifest_path, 'r' ).read()
+        self.manifest_dictionary = yaml_load(load_string)
 
     def verify_manifest( self, mapping_dict ):
         """Loop through keys in manifest file, checking for files and
@@ -87,7 +99,7 @@ class FileManifest:
         tuple_check_list = []
         for subdir in self.manifest_dictionary.keys():
             for inode in self.manifest_dictionary[subdir]:
-                new_tuple = ( os.path.join( mapping_dict[subdir], inode ),
+                new_tuple = ( make_path( mapping_dict[subdir], inode ),
                               self.manifest_dictionary[subdir][inode] )
                 tuple_check_list.append( new_tuple )
         error_list = self.verify_file_md5_tuples( tuple_check_list )
@@ -100,7 +112,7 @@ class FileManifest:
         for file_tuple in file_md5_tuple_list:
             filepath = file_tuple[0]
             md5sum = file_tuple[1]
-            lastslash = filepath.rfind( os.sep )+1
+            lastslash = filepath.rfind( '/' )+1
             base = filepath[0:lastslash]
             if not os.path.isdir(base):
                 err_string = "missing directory"
@@ -109,7 +121,7 @@ class FileManifest:
                 err_string = "missing file"
                 error_list.append((filepath, err_string))
             elif md5sum != '':
-                computed = hashlib.md5(open(filepath, 'rb').read()).hexdigest()
+                computed = md5_sum(open(filepath, 'rb').read())
                 if md5sum != computed:
                     err_string = "invalid checksum: Actual: %s Expected %s" \
                                  % (computed, md5sum)
